==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/ronportal/common/poznamkykedniformular.php <==
<?php
/**
 * stanislav.elbl, 04.02.2021
 */

namespace RonPortal\Common;

use Ron\Controls\FormField;
use Ron\DB\Database;
use Ron\StringUtils;
use RonPortal\Controls\RonPortalForm;
use RonPortal\Kapacity\KapacitySettings;
use RonPortal\Kapacity\KapacityUtils;
use RonPortal\Prava;
use RonPortal\RonPortalSettings;
use RonPortal\RozdeleniUtils;
use RonPortal\TypRozdeleni;

class PoznamkyKeDniFormular extends RonPortalForm
{
    /**
     * VkladaniVyrobyFormular constructor.
     * @param Database $database
     * @throws \Exception
     */
    public function __construct($database)
    {
        parent::__construct($database, 'new', true); // dialogMode = true

        $this ->cssClass = 'large-form rondialog ronform form-30-70';
        $this ->code = 'formpoznamkykedni';

        $this ->setXmlEventsName('POZNAMKA_KE_DNI');

        $this ->stornoAction = "#";

        $this ->htmlParams = array_merge($this ->htmlParams, [
            'id' => 'poznamky_ke_dni_dialog',
            //'data-ronform-url' => '?menuid=monitorovaniv&action=loaddata',
            //'data-ronform-submit-url' => '?menuid=monitorovaniv&action=vlozpuvodni',
            'data-ronform-after-submit' => 'reload',
            'data-ronform-url' => '?menuid=poznamkykedni&action=loaddata&record=',
            'data-ronform-submit-url' => '?menuid=poznamkykedni&action=storedata',
            'title' => \Ron\ronText('Poznamka_ke_dni')
        ]);

        $this ->sqlTableName = 'PoznamkaKeDni';

        $this ->addField(FormField::FIELD_TYPE_ID)
            ->setFieldName('id') ->setFieldId('poznamkakedni_form_id')
            ->setPrimary(true)
            ->setFieldCssClass('ronform-field');

        $this ->addField(FormField::FIELD_TYPE_DATE)
            ->setFieldName('datumOd') ->setFieldId('poznamka_datumod') ->setCaption('Datum_od') ->setRequired(true)
            ->setCode('field-datumod')
            ->setFieldCssClass('ronform-field')
            ->setDefaultValue(StringUtils::format('date', time()))
            ->setOtherHtmlParams(['data-roncalendar-next' => 'datumDo']);

        $this ->addField(FormField::FIELD_TYPE_DATE)
            ->setFieldName('datumDo') ->setFieldId('poznamka_datumdo') ->setCaption('Datum_do') ->setRequired(true)
            ->setCode('field-datumdo')
            ->setFieldCssClass('ronform-field')
            ->setDefaultValue(StringUtils::format('date', time()))
            ->setOtherHtmlParams(['data-roncalendar-prev' => 'datumOd']);

        $this ->addField()
            ->setFieldName('popis') ->setFieldId('poznamka_popis')->setCaption('Popis') ->setRequired(true)
            ->setCode('field-popis')
            ->setFieldCssClass('form-input ronform-field');

        $this ->addField(FormField::FIELD_TYPE_SELECT)
            ->setFieldName('typ') ->setFieldId('poznamka_typ') ->setCaption('Typ_poznamky') ->setRequired(true)
            ->setCode('field-typ')
            ->setSelectSql(
                'SELECT Kod, Popis FROM TypPoznamkyKeDni ORDER BY Popis')
            ->setFieldCssClass('form-control ronform-field');

        $this ->addField(FormField::FIELD_TYPE_MEMO)
            ->setFieldName('poznamka') ->setFieldId('poznamka_poznamka')->setCaption('Poznamka')
            ->setFieldCssClass('form-control ronform-field');

        $typRozdeleni = TypRozdeleni::getTypRozdeleni($database,
            KapacitySettings::typRozdeleniProVyber());

        $this->addField(FormField::FIELD_TYPE_CONSTANT)
            ->setFieldName('KodTypuRozdeleni') ->setDataType('int')
            ->setCode('field-kodtypurozdeleni')
            ->setDefaultValue($typRozdeleni ->kod);

        $prava = Prava::vratPrava('poznamkykedni');
        $filter = ($prava ->typRozdeleni === $typRozdeleni ->kod)
            ? $prava ->sqlfiltrRozdeleni(time(), time())
            : null;

        $sql =
            'SELECT Kod, Popis FROM Rozdeleni' .
            ' WHERE KodTypuRozdeleni = ' . $typRozdeleni ->kod .
            ($filter ? ' AND ' . $filter : '') .
            ' ORDER BY Popis';

        $this->addField(FormField::FIELD_TYPE_SELECT)
            ->setFieldName('Rozdeleni') ->setRequired(true)
            ->setCode('field-rozdeleni')
            ->setCaption(StringUtils::htmlTextConvert($typRozdeleni ->popis))->setShowEmptyValue(true)
            ->setFieldCssClass('form-control ronselect ronform-field')
            ->setOtherHtmlParams('data-columns="text;value"')
            ->setSelectSql($sql);

//        $this ->addField(FORM_FIELD_TYPE_SELECT)
//            ->setFieldName('KodVyrobniCinnosti')
//            ->setCode('field-operace')
//            ->setCaption('Vyroba_cinnost')
//            ->setRequired(true) ->setFieldId('vkladani_vyrobni_cinnost')
//            ->setSelectSql(
//                'SELECT Kod, Popis,' .
//                ' T_ZadavatVyrobek, T_ZadavatVyrobniCislo, T_ZadavatZakazku, T_ZadavatMnozstviDobre, T_ZadavatMnozstviSpatne, T_ZadavatCas, T_TypZadavaniCasu' .
//                ' FROM VyrobniCinnost WHERE Aktivni = 1 ORDER BY Popis')
//            ->setFieldCssClass('form-control ronselect')
//            ->setAttrIndexes([
//                'data-zadavat-vyrobek' => 2, 'data-zadavat-vyrobni-cislo' => 3,
//                'data-zadavat-zakazku' => 4, 'data-zadavat-mnozstvi-dobre' => 5, 'data-zadavat-mnozstvi-spatne' => 6,
//                'data-zadavat-cas' => 7, 'data-typ-zadavani-casu' => 8]);

//        $params = $this ->database ->createParameters();
//        $this ->addField(FORM_FIELD_TYPE_SELECT)
//            ->setFieldName('Rozdeleni')
//            ->setCode('field-rozdeleni')
//            ->setCaption('Rozdeleni')
//            ->setFieldId('poznamkakedni_form_rozdeleni')
//            ->setSelectSql(
//                new SqlStatement(
//                    'SELECT Kod, Popis FROM Rozdeleni' .
//                    ' WHERE KodTypuRozdeleni'
//                    ' WHERE PlatnostOd <= ' . $params ->addParameter($this ->database ->dateToParam(time())) .
//                    ' AND (PlatnostDo >= ' .$params ->addParameter($this ->database ->dateToParam(time())) . ' OR PlatnostDo IS NULL)',
//                    $params
//                ))
//            ->setFieldCssClass('form-control ronselect')
//            ->setShowEmptyValue(true);
    }

}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2311_175.zip: ronportal/ronportal/common/poznamkykedniformular.php <==
<?php
/**
 * stanislav.elbl, 04.02.2021
 */

namespace RonPortal\Common;

use Ron\Controls\FormField;
use Ron\DB\Database;
use Ron\StringUtils;
use RonPortal\Controls\RonPortalForm;
use RonPortal\Kapacity\KapacitySettings;
use RonPortal\Kapacity\KapacityUtils;
use RonPortal\Prava;
use RonPortal\RonPortalSettings;
use RonPortal\RozdeleniUtils;
use RonPortal\TypRozdeleni;

class PoznamkyKeDniFormular extends RonPortalForm
{
    /**
     * VkladaniVyrobyFormular constructor.
     * @param Database $database
     * @throws \Exception
     */
    public function __construct($database)
    {
        parent::__construct($database, 'new', true); // dialogMode = true

        $this ->cssClass = 'large-form rondialog ronform form-30-70';
        $this ->code = 'formpoznamkykedni';

        $this ->setXmlEventsName('POZNAMKA_KE_DNI');

        $this ->stornoAction = "#";

        $this ->htmlParams = array_merge($this ->htmlParams, [
            'id' => 'poznamky_ke_dni_dialog',
            //'data-ronform-url' => '?menuid=monitorovaniv&action=loaddata',
            //'data-ronform-submit-url' => '?menuid=monitorovaniv&action=vlozpuvodni',
            'data-ronform-after-submit' => 'reload',
            'data-ronform-url' => '?menuid=poznamkykedni&action=loaddata&record=',
            'data-ronform-submit-url' => '?menuid=poznamkykedni&action=storedata',
            'title' => \Ron\ronText('Poznamka_ke_dni')
        ]);

        $this ->sqlTableName = 'PoznamkaKeDni';

        $this ->addField(FormField::FIELD_TYPE_ID)
            ->setFieldName('id') ->setFieldId('poznamkakedni_form_id')
            ->setPrimary(true)
            ->setFieldCssClass('ronform-field');

        $this ->addField(FormField::FIELD_TYPE_DATE)
            ->setFieldName('datumOd') ->setFieldId('poznamka_datumod') ->setCaption('Datum_od') ->setRequired(true)
            ->setCode('field-datumod')
            ->setFieldCssClass('ronform-field')
            ->setDefaultValue(StringUtils::format('date', time()))
            ->setOtherHtmlParams(['data-roncalendar-next' => 'datumDo']);

        $this ->addField(FormField::FIELD_TYPE_DATE)
            ->setFieldName('datumDo') ->setFieldId('poznamka_datumdo') ->setCaption('Datum_do') ->setRequired(true)
            ->setCode('field-datumdo')
            ->setFieldCssClass('ronform-field')
            ->setDefaultValue(StringUtils::format('date', time()))
            ->setOtherHtmlParams(['data-roncalendar-prev' => 'datumOd']);

        $this ->addField()
            ->setFieldName('popis') ->setFieldId('poznamka_popis')->setCaption('Popis') ->setRequired(true)
            ->setCode('field-popis')
            ->setFieldCssClass('form-control ronform-field');

        $this ->addField(FormField::FIELD_TYPE_SELECT)
            ->setFieldName('typ') ->setFieldId('poznamka_typ') ->setCaption('Typ_poznamky') ->setRequired(true)
            ->setCode('field-typ')
            ->setSelectSql(
                'SELECT Kod, Popis FROM TypPoznamkyKeDni WHERE %FILTER% ORDER BY %ORDER%', '1 = 1', 'Popis')
            ->setFieldCssClass('form-control ronform-field');

        $this ->addField(FormField::FIELD_TYPE_MEMO)
            ->setFieldName('poznamka') ->setFieldId('poznamka_poznamka')->setCaption('Poznamka')
            ->setFieldCssClass('form-control ronform-field');

        $typRozdeleni = TypRozdeleni::getTypRozdeleni($database,
            KapacitySettings::typRozdeleniProVyber());

        $this->addField(FormField::FIELD_TYPE_CONSTANT)
            ->setFieldName('KodTypuRozdeleni') ->setDataType('int')
            ->setCode('field-kodtypurozdeleni')
            ->setDefaultValue($typRozdeleni ->kod);

        $prava = Prava::vratPrava('poznamkykedni');
        $filter = ($prava ->typRozdeleni === $typRozdeleni ->kod)
            ? $prava ->sqlfiltrRozdeleni(time(), time())
            : null;

        $sql =
            'SELECT Kod, Popis FROM Rozdeleni' .
            ' WHERE KodTypuRozdeleni = ' . $typRozdeleni ->kod .
            ($filter ? ' AND ' . $filter : '') .
            ' ORDER BY Popis';

        $this->addField(FormField::FIELD_TYPE_SELECT)
            ->setFieldName('Rozdeleni') ->setRequired(true)
            ->setCode('field-rozdeleni')
            ->setCaption(StringUtils::htmlTextConvert($typRozdeleni ->popis))->setShowEmptyValue(true)
            ->setFieldCssClass('form-control ronselect ronform-field')
            ->setOtherHtmlParams('data-columns="text;value"')
            ->setSelectSql($sql);

//        $this ->addField(FORM_FIELD_TYPE_SELECT)
//            ->setFieldName('KodVyrobniCinnosti')
//            ->setCode('field-operace')
//            ->setCaption('Vyroba_cinnost')
//            ->setRequired(true) ->setFieldId('vkladani_vyrobni_cinnost')
//            ->setSelectSql(
//                'SELECT Kod, Popis,' .
//                ' T_ZadavatVyrobek, T_ZadavatVyrobniCislo, T_ZadavatZakazku, T_ZadavatMnozstviDobre, T_ZadavatMnozstviSpatne, T_ZadavatCas, T_TypZadavaniCasu' .
//                ' FROM VyrobniCinnost WHERE Aktivni = 1 ORDER BY Popis')
//            ->setFieldCssClass('form-control ronselect')
//            ->setAttrIndexes([
//                'data-zadavat-vyrobek' => 2, 'data-zadavat-vyrobni-cislo' => 3,
//                'data-zadavat-zakazku' => 4, 'data-zadavat-mnozstvi-dobre' => 5, 'data-zadavat-mnozstvi-spatne' => 6,
//                'data-zadavat-cas' => 7, 'data-typ-zadavani-casu' => 8]);

//        $params = $this ->database ->createParameters();
//        $this ->addField(FORM_FIELD_TYPE_SELECT)
//            ->setFieldName('Rozdeleni')
//            ->setCode('field-rozdeleni')
//            ->setCaption('Rozdeleni')
//            ->setFieldId('poznamkakedni_form_rozdeleni')
//            ->setSelectSql(
//                new SqlStatement(
//                    'SELECT Kod, Popis FROM Rozdeleni' .
//                    ' WHERE KodTypuRozdeleni'
//                    ' WHERE PlatnostOd <= ' . $params ->addParameter($this ->database ->dateToParam(time())) .
//                    ' AND (PlatnostDo >= ' .$params ->addParameter($this ->database ->dateToParam(time())) . ' OR PlatnostDo IS NULL)',
//                    $params
//                ))
//            ->setFieldCssClass('form-control ronselect')
//            ->setShowEmptyValue(true);
    }

}
